#!/usr/bin/perl

#
# This small script "convert" sample VIRTIS view direction angle file
# provided by Giuseppe Piccioni on Dec into a format acceptable for
# input into SPICE program MSOPCK.
#

#
# Take lines from STDIN.
#
while( $line = <STDIN> ) {

  #
  # Process only lines that start with a number (i.e. with SCLK time tag.)
  #
  if ( $line =~ /^\d/ ) {

    #
    # Split line into words.
    #
    chop( $line );
    @t = split( ' ', $line );

    #
    # Convert SCLK from decimal representation to SPICE format.
    #
    ( $sec, $msec ) = split( /\./, $t[0] );
    $msec = "0.$msec";
    $sclk = sprintf( "%08d:%05d", $sec, $msec * 256 * 256 );

    #
    # Print MSOPCK input line containing SPICE-style SCLK,
    # angle converted to radians and zero for the other two
    # input angles.
    #
    printf ( "%18s %16.8f   0.0   0.0\n", $sclk, -$t[2]/1000.0 );

  }

}

exit;
